import { createRouter, createWebHistory } from "vue-router";
import PageLayout from '../layout/pageLayout.vue'

const router = createRouter({
  history: createWebHistory(),
  routes: [
    {
      path: "/",
      component: PageLayout,
      redirect: "/model", 
      children: [
        {
          path: "/model",
          name: "model",
          redirect: "/model/landerModel",
          component: () => import("../views/model/index.vue"),
          children: [
            {
              path: "/model/landerModel",
              name: "landerModel",
              component: () => import("../views/model/children/landerModel.vue"),
            },
            {
              path: "/model/roverModel",
              name: "roverModel",
              component: () => import("../views/model/children/roverModel.vue"),
            },
            {
              path: "/model/leapMachineModel",
              name: "leapMachineModel",
              component: () =>
                import("../views/model/children/leapMachineModel.vue"),
            },
          ],
        },
        {
          path: "/simulation",
          name: "simulation",
          component: () => import("../views/simulation/index.vue"),
          redirect: "/testSimulation",
          meta: {
            name: '测试仿真'
          },
          children: [
            {
              path: "/testSimulation",
              name: "testSimulation",
              component: () =>
                import("../views/simulation/testSimulation/index.vue"),
            },
            {
              path: "/testSimulation/detail",
              name: "testSimulation-detail",
              component: () =>
                import("../views/simulation/testSimulation/detail.vue"),
            },
            {
              path: "/testSimulation/testReport",
              name: "testReport",
              component: () =>
                import("../views/simulation/testSimulation/testReport.vue"),
            },
            {
              path: "/realTimeSimulation",
              name: "realTimeSimulation",
              meta: {
                name: '实时仿真'
              },
              component: () =>
                import("../views/simulation/realTimeSimulation/index.vue"),
            },
            {
              path: "/autonomousFunction",
              name: "autonomousFunction",
              meta: {
                name: '自主功能'
              },
              component: () =>
                import("../views/simulation/autonomousFunction/index.vue"),
            },
          ],
        },
       
        {
          path: "/systemManage",
          name: "systemManage",
          meta: {
            name: '系统管理'
          },
          component: () => import("../views/system/index.vue"),
          redirect: "/userManage",
          children: [
            {
              path: "/userManage",
              name: "userManage",
              meta: {
                name: '用户管理'
              },
              component: () =>
                import("../views/system/userManage.vue"),
            },
            {
              path: "/roleManage",
              name: "roleManage",
              meta: {
                name: '角色管理'
              },
              component: () =>
                import("../views/system/roleManage.vue"),
            },
          ]
        },
      ],
    }
  ]
});

export default router;
